                <h3><lang en="Please enter your OpenID login" fr="Entrez votre identifiant OpenID"/></h3>

                <table>
                <tr>
                <td><input name="openid_identifier" type="text" /></td>
                </tr>
                <tr><td>
                <div class="buttons">
                <button type="reset" class="negative" tabindex="4">
                        <img src="/skins/common/cancel.png" alt="" />
                        <lang en="Cancel" fr="Annuler" />
                </button>
                <button type="submit" class="positive" tabindex="3">
                        <img src="/skins/common/accept.png" alt="" />
                        <lang en="Connect" fr="Se connecter" />
                </button>
                </div></td></tr>
                </table>

